cmd

package
v0.1.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 4, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Overview

Copyright © 2023 NAME HERE <EMAIL ADDRESS>

Index

Constants

This section is empty.

Variables

var RootCmd = &cobra.Command{
	Use:   "mpagd_util",
	Short: `MPAGD Utility CLI Version:` + appVersion,
	Long:  `A command line interface for MPAGD utility functions. Version:` + appVersion,
}

RootCmd represents the base command when called without any subcommands

Functions

func Cmd_AutoBackup

func Cmd_AutoBackup() *cobra.Command

Cmd_AutoBackup creates a command to enable automatic backups.

func Cmd_Backup

func Cmd_Backup() *cobra.Command

Cmd_Backup creates a command to back up a project file.

func Cmd_CreateProjectFromTemplate

func Cmd_CreateProjectFromTemplate() *cobra.Command

Cmd_CreateProjectFromTemplate creates a command to create a project from a template.

func Cmd_ImportAGD

func Cmd_ImportAGD() *cobra.Command

Cmd_ImportAGD creates a command to import all AGD elements into the project file.

func Cmd_ImportAGDSelective

func Cmd_ImportAGDSelective() *cobra.Command

Cmd_ImportAGDSelective creates a command to import selected AGD elements into the project file.

func Cmd_ImportBlocks

func Cmd_ImportBlocks() *cobra.Command

Cmd_ImportBlocks creates a command to import DEFINEBLOCK elements from an AGD file into an APJ file.

func Cmd_ImportFont

func Cmd_ImportFont() *cobra.Command

Cmd_ImportFont creates a command to import font elements from an AGD file into an APJ file.

func Cmd_ImportHeader

func Cmd_ImportHeader() *cobra.Command

Cmd_ImportHeader creates the "import" subcommand for importing header elements.

func Cmd_ImportKeys

func Cmd_ImportKeys() *cobra.Command

func Cmd_ImportLivesScore

func Cmd_ImportLivesScore() *cobra.Command

Cmd_ImportLivesScore creates the "import" subcommand for LivesScore management.

func Cmd_ImportMap

func Cmd_ImportMap() *cobra.Command

func Cmd_ImportObjects

func Cmd_ImportObjects() *cobra.Command

Cmd_ImportObjects creates a command to import Objects elements from an AGD file into an APJ file.

func Cmd_ImportScreens

func Cmd_ImportScreens() *cobra.Command

Cmd_ImportScreens creates a command to import Screens elements from an AGD file into an APJ file.

func Cmd_ImportSpritePos

func Cmd_ImportSpritePos() *cobra.Command

Cmd_ImportSpritePos creates a command to import SpritePos elements from an AGD file into an APJ file.

func Cmd_ImportSprites

func Cmd_ImportSprites() *cobra.Command

func Cmd_ImportULAPalette

func Cmd_ImportULAPalette() *cobra.Command

Cmd_ImportULAPalette creates a command to import ULAPalette elements from an AGD file into an APJ file.

func Cmd_ImportWindows

func Cmd_ImportWindows() *cobra.Command

Cmd_ImportWindows creates a command to import Windows elements from an AGD file into an APJ file.

func Cmd_ListBackups

func Cmd_ListBackups() *cobra.Command

Cmd_ListBackups creates a command to list all backup files.

func Cmd_ListTemplates

func Cmd_ListTemplates() *cobra.Command

Cmd_ListTemplates creates a command to list all available project templates.

func Cmd_LoadYAML

func Cmd_LoadYAML() *cobra.Command

Cmd_LoadYAML creates a command to load a project from a YAML file.

func Cmd_ProjectStats

func Cmd_ProjectStats() *cobra.Command

Cmd_ProjectStats creates a command to display statistics about the project.

func Cmd_PurgeBackup

func Cmd_PurgeBackup() *cobra.Command

Cmd_PurgeBackup creates a command to purge all backup files.

func Cmd_RenderBlock

func Cmd_RenderBlock() *cobra.Command

Cmd_RenderBlock creates a command to render blocks to the terminal.

func Cmd_RenderBlocksToBitmap

func Cmd_RenderBlocksToBitmap() *cobra.Command

Cmd_RenderBlocksToBitmap creates a command to render blocks to a bitmap file.

func Cmd_RenderScreensToBitmap

func Cmd_RenderScreensToBitmap() *cobra.Command

Cmd_RenderScreensToBitmap creates a command to render a screen from an APJ file to a bitmap image.

func Cmd_RenderSprite

func Cmd_RenderSprite() *cobra.Command

func Cmd_RenderSpriteToBitmap

func Cmd_RenderSpriteToBitmap() *cobra.Command

func Cmd_ReorderBlocks

func Cmd_ReorderBlocks() *cobra.Command

Cmd_ReorderBlocks creates a command to reorder blocks in the MPAGD project.

func Cmd_ReorderScreens added in v0.1.4

func Cmd_ReorderScreens() *cobra.Command

Cmd_ReorderScreens creates a command to reorder screens in an APJ file.

func Cmd_ReorderSprites added in v0.1.4

func Cmd_ReorderSprites() *cobra.Command

Cmd_ReorderSprites creates a command to reorder sprites in the MPAGD project.

func Cmd_Restore

func Cmd_Restore() *cobra.Command

Cmd_Restore creates a command to restore a project file from the last backup.

func Cmd_RotateBlockCCW90

func Cmd_RotateBlockCCW90() *cobra.Command

Cmd_RotateBlockCCW90 creates a command to rotate a block 90 degrees counter-clockwise.

func Cmd_RotateBlockCW90

func Cmd_RotateBlockCW90() *cobra.Command

Cmd_RotateBlockCW90 creates a command to rotate a block 90 degrees clockwise.

func Cmd_RotateSpritesCCW90

func Cmd_RotateSpritesCCW90() *cobra.Command

func Cmd_RotateSpritesCW90

func Cmd_RotateSpritesCW90() *cobra.Command

func Cmd_SaveAsYAML

func Cmd_SaveAsYAML() *cobra.Command

Cmd_SaveAsYAML creates a command to save the project file as a YAML file.

func Execute

func Execute()

func GenerateDoc

func GenerateDoc() *cobra.Command

GenerateDoc creates a new command to generate CLI documentation.

func SetNoColor added in v0.1.4

func SetNoColor(no_color bool)

func Version added in v0.1.6

func Version() *cobra.Command

Types

This section is empty.

Jump to