Documentation
¶
Overview ¶
Copyright © 2023 NAME HERE <EMAIL ADDRESS>
Index ¶
- Variables
- func Cmd_AutoBackup() *cobra.Command
- func Cmd_Backup() *cobra.Command
- func Cmd_CreateProjectFromTemplate() *cobra.Command
- func Cmd_ImportAGD() *cobra.Command
- func Cmd_ImportAGDSelective() *cobra.Command
- func Cmd_ImportBlocks() *cobra.Command
- func Cmd_ImportFont() *cobra.Command
- func Cmd_ImportHeader() *cobra.Command
- func Cmd_ImportKeys() *cobra.Command
- func Cmd_ImportLivesScore() *cobra.Command
- func Cmd_ImportMap() *cobra.Command
- func Cmd_ImportObjects() *cobra.Command
- func Cmd_ImportScreens() *cobra.Command
- func Cmd_ImportSpritePos() *cobra.Command
- func Cmd_ImportSprites() *cobra.Command
- func Cmd_ImportULAPalette() *cobra.Command
- func Cmd_ImportWindows() *cobra.Command
- func Cmd_ListBackups() *cobra.Command
- func Cmd_ListTemplates() *cobra.Command
- func Cmd_LoadYAML() *cobra.Command
- func Cmd_ProjectStats() *cobra.Command
- func Cmd_PurgeBackup() *cobra.Command
- func Cmd_RenderBlock() *cobra.Command
- func Cmd_RenderBlocksToBitmap() *cobra.Command
- func Cmd_RenderScreensToBitmap() *cobra.Command
- func Cmd_RenderSprite() *cobra.Command
- func Cmd_RenderSpriteToBitmap() *cobra.Command
- func Cmd_ReorderBlocks() *cobra.Command
- func Cmd_ReorderScreens() *cobra.Command
- func Cmd_ReorderSprites() *cobra.Command
- func Cmd_Restore() *cobra.Command
- func Cmd_RotateBlockCCW90() *cobra.Command
- func Cmd_RotateBlockCW90() *cobra.Command
- func Cmd_RotateSpritesCCW90() *cobra.Command
- func Cmd_RotateSpritesCW90() *cobra.Command
- func Cmd_SaveAsYAML() *cobra.Command
- func Execute()
- func GenerateDoc() *cobra.Command
- func SetNoColor(no_color bool)
- func Version() *cobra.Command
Constants ¶
This section is empty.
Variables ¶
var RootCmd = &cobra.Command{
Use: "mpagd_util",
Short: `MPAGD Utility CLI Version:` + appVersion,
Long: `A command line interface for MPAGD utility functions. Version:` + appVersion,
}
RootCmd represents the base command when called without any subcommands
Functions ¶
func Cmd_AutoBackup ¶
Cmd_AutoBackup creates a command to enable automatic backups.
func Cmd_Backup ¶
Cmd_Backup creates a command to back up a project file.
func Cmd_CreateProjectFromTemplate ¶
Cmd_CreateProjectFromTemplate creates a command to create a project from a template.
func Cmd_ImportAGD ¶
Cmd_ImportAGD creates a command to import all AGD elements into the project file.
func Cmd_ImportAGDSelective ¶
Cmd_ImportAGDSelective creates a command to import selected AGD elements into the project file.
func Cmd_ImportBlocks ¶
Cmd_ImportBlocks creates a command to import DEFINEBLOCK elements from an AGD file into an APJ file.
func Cmd_ImportFont ¶
Cmd_ImportFont creates a command to import font elements from an AGD file into an APJ file.
func Cmd_ImportHeader ¶
Cmd_ImportHeader creates the "import" subcommand for importing header elements.
func Cmd_ImportKeys ¶
func Cmd_ImportLivesScore ¶
Cmd_ImportLivesScore creates the "import" subcommand for LivesScore management.
func Cmd_ImportMap ¶
func Cmd_ImportObjects ¶
Cmd_ImportObjects creates a command to import Objects elements from an AGD file into an APJ file.
func Cmd_ImportScreens ¶
Cmd_ImportScreens creates a command to import Screens elements from an AGD file into an APJ file.
func Cmd_ImportSpritePos ¶
Cmd_ImportSpritePos creates a command to import SpritePos elements from an AGD file into an APJ file.
func Cmd_ImportSprites ¶
func Cmd_ImportULAPalette ¶
Cmd_ImportULAPalette creates a command to import ULAPalette elements from an AGD file into an APJ file.
func Cmd_ImportWindows ¶
Cmd_ImportWindows creates a command to import Windows elements from an AGD file into an APJ file.
func Cmd_ListBackups ¶
Cmd_ListBackups creates a command to list all backup files.
func Cmd_ListTemplates ¶
Cmd_ListTemplates creates a command to list all available project templates.
func Cmd_LoadYAML ¶
Cmd_LoadYAML creates a command to load a project from a YAML file.
func Cmd_ProjectStats ¶
Cmd_ProjectStats creates a command to display statistics about the project.
func Cmd_PurgeBackup ¶
Cmd_PurgeBackup creates a command to purge all backup files.
func Cmd_RenderBlock ¶
Cmd_RenderBlock creates a command to render blocks to the terminal.
func Cmd_RenderBlocksToBitmap ¶
Cmd_RenderBlocksToBitmap creates a command to render blocks to a bitmap file.
func Cmd_RenderScreensToBitmap ¶
Cmd_RenderScreensToBitmap creates a command to render a screen from an APJ file to a bitmap image.
func Cmd_RenderSprite ¶
func Cmd_ReorderBlocks ¶
Cmd_ReorderBlocks creates a command to reorder blocks in the MPAGD project.
func Cmd_ReorderScreens ¶ added in v0.1.4
Cmd_ReorderScreens creates a command to reorder screens in an APJ file.
func Cmd_ReorderSprites ¶ added in v0.1.4
Cmd_ReorderSprites creates a command to reorder sprites in the MPAGD project.
func Cmd_Restore ¶
Cmd_Restore creates a command to restore a project file from the last backup.
func Cmd_RotateBlockCCW90 ¶
Cmd_RotateBlockCCW90 creates a command to rotate a block 90 degrees counter-clockwise.
func Cmd_RotateBlockCW90 ¶
Cmd_RotateBlockCW90 creates a command to rotate a block 90 degrees clockwise.
func Cmd_RotateSpritesCCW90 ¶
func Cmd_RotateSpritesCW90 ¶
func Cmd_SaveAsYAML ¶
Cmd_SaveAsYAML creates a command to save the project file as a YAML file.
func GenerateDoc ¶
GenerateDoc creates a new command to generate CLI documentation.
func SetNoColor ¶ added in v0.1.4
func SetNoColor(no_color bool)
Types ¶
This section is empty.